@@ -4,19 +4,21 @@ algorithms, including among others PCA, NMF or ICA. Most of the algorithms of
 this module can be regarded as dimensionality reduction techniques.
 """
 
-from .nmf import NMF, non_negative_factorization
-from .pca import PCA, RandomizedPCA
-from .incremental_pca import IncrementalPCA
-from .kernel_pca import KernelPCA
-from .sparse_pca import SparsePCA, MiniBatchSparsePCA
-from .truncated_svd import TruncatedSVD
-from .fastica_ import FastICA, fastica
-from .dict_learning import (dict_learning, dict_learning_online, sparse_encode,
-                            DictionaryLearning, MiniBatchDictionaryLearning,
-                            SparseCoder)
-from .factor_analysis import FactorAnalysis
+
+from ._nmf import NMF, non_negative_factorization
+from ._pca import PCA
+from ._incremental_pca import IncrementalPCA
+from ._kernel_pca import KernelPCA
+from ._sparse_pca import SparsePCA, MiniBatchSparsePCA
+from ._truncated_svd import TruncatedSVD
+from ._fastica import FastICA, fastica
+from ._dict_learning import (dict_learning, dict_learning_online,
+                             sparse_encode, DictionaryLearning,
+                             MiniBatchDictionaryLearning, SparseCoder)
+from ._factor_analysis import FactorAnalysis
 from ..utils.extmath import randomized_svd
-from .online_lda import LatentDirichletAllocation
+from ._lda import LatentDirichletAllocation
+
 
 __all__ = ['DictionaryLearning',
            'FastICA',
@@ -26,7 +28,6 @@ __all__ = ['DictionaryLearning',
            'MiniBatchSparsePCA',
            'NMF',
            'PCA',
-           'RandomizedPCA',
            'SparseCoder',
            'SparsePCA',
            'dict_learning',
